@@ -49,9 +49,6 @@ int main(int argc, char **argv)
     chaz_VariadicMacros_run();
 
     /* Write custom postamble. */
-    if (chaz_HeadCheck_check_header("sys/mman.h")) {
-        chaz_ConfWriter_append_conf("#define CHY_HAS_SYS_MMAN_H\n\n");
-    }
     chaz_ConfWriter_append_conf(
         "#ifdef CHY_HAS_SYS_TYPES_H\n"
         "  #include <sys/types.h>\n"
@@ -73,7 +70,7 @@ int main(int argc, char **argv)
     return 0;
 }
 
-/* Copyright 2006-2010 Marvin Humphrey
+/* Copyright 2006-2011 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
  * under the same terms as Perl itself.
