@@ -43,8 +43,7 @@ sub write_h {
         if ( a_isa_b( $block, 'Clownfish::Parcel' ) ) { }
         elsif ( a_isa_b( $block, 'Clownfish::Class' ) ) {
             my $class_binding
-                = Clownfish::Binding::Core::Class->new( client => $block,
-                );
+                = Clownfish::Binding::Core::Class->new( client => $block, );
             $content .= $class_binding->to_c_header . "\n";
         }
         elsif ( a_isa_b( $block, 'Clownfish::CBlock' ) ) {
@@ -101,13 +100,14 @@ sub write_c {
         or confess("Can't open '$c_path' for writing");
 
     # Aggregate content.
-    my $content = "";
+    my $content     = "";
     my $c_file_syms = "";
     for my $block ( $file->blocks ) {
         if ( blessed($block) ) {
             if ( $block->isa('Clownfish::Class') ) {
-                my $bound = Clownfish::Binding::Core::Class->new(
-                    client => $block, );
+                my $bound
+                    = Clownfish::Binding::Core::Class->new( client => $block,
+                    );
                 $content .= $bound->to_c . "\n";
                 my $c_file_sym = "C_" . uc( $block->full_struct_sym );
                 $c_file_syms .= "#define $c_file_sym\n";
@@ -144,17 +144,17 @@ __POD__
 
 =head1 NAME
 
-Clownfish::Binding::Core::File - Generate core C code for a .bp file.
+Clownfish::Binding::Core::File - Generate core C code for a Clownfish file.
 
 =head1 DESCRIPTION
 
 This module is the companion to Clownfish::File, generating the C code
-needed to implement the .bp file's specification.
+needed to implement the file's specification.
 
-There is a one-to-one mapping between .bp files and autogenerated .h and .c
-files.  If Foo.bp includes both Foo and Foo::FooJr, then it is necessary to
-pound-include "Foo.h" in order to get FooJr's interface -- not "Foo/FooJr.h",
-which won't exist.
+There is a one-to-one mapping between Clownfish header files and autogenerated
+.h and .c files.  If Foo.cfh includes both Foo and Foo::FooJr, then it is
+necessary to pound-include "Foo.h" in order to get FooJr's interface -- not
+"Foo/FooJr.h", which won't exist.
 
 =head1 CLASS METHODS
 
@@ -198,10 +198,9 @@ Generate a C file containing code needed by the class implementations.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2010 Marvin Humphrey
+Copyright 2008-2011 Marvin Humphrey
 
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
 =cut
-
