@@ -207,6 +207,9 @@ S_discover_unused(FilePurger *self, VArray **purgables_ptr,
 
             // DON'T obtain the lock -- only see whether another
             // entity holds a lock on the snapshot file.
+            if (lock) {
+                Lock_Clear_Stale(lock);
+            }
             if (lock && Lock_Is_Locked(lock)) {
                 // The snapshot file is locked, which means someone's using
                 // that version of the index -- protect all of its entries.
@@ -272,7 +275,7 @@ S_find_all_referenced(Folder *folder, VArray *entries)
     return referenced;
 }
 
-/* Copyright 2007-2010 Marvin Humphrey
+/* Copyright 2007-2011 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
  * under the same terms as Perl itself.
