@@ -98,7 +98,7 @@ HLWriter_add_inverted_doc(HighlightWriter *self, Inverter *inverter,
     OutStream_Write_I64(ix_out, filepos);
 
     // Count, then write number of highlightable fields. 
-    Inverter_Iter_Init(inverter);
+    Inverter_Iterate(inverter);
     while (Inverter_Next(inverter)) {
         FieldType *type = Inverter_Get_Type(inverter);
         if (   FType_Is_A(type, FULLTEXTTYPE) 
@@ -109,7 +109,7 @@ HLWriter_add_inverted_doc(HighlightWriter *self, Inverter *inverter,
     }
     OutStream_Write_C32(dat_out, num_highlightable);
 
-    Inverter_Iter_Init(inverter);
+    Inverter_Iterate(inverter);
     while (Inverter_Next(inverter)) {
         FieldType *type = Inverter_Get_Type(inverter);
         if (   FType_Is_A(type, FULLTEXTTYPE) 
@@ -256,7 +256,7 @@ HLWriter_format(HighlightWriter *self)
     return HLWriter_current_file_format;
 }
 
-/* Copyright 2006-2010 Marvin Humphrey
+/* Copyright 2006-2011 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
  * under the same terms as Perl itself.
