@@ -17,11 +17,10 @@
 #include "KinoSearch/Util/IndexFileNames.h"
 #include "KinoSearch/Util/StringHelper.h"
 
-// Obtain/release read locks and commit locks.  If self->manager is
-// NULL, do nothing.
-static void 
+// Obtain/release read locks and commit locks.
+static bool_t
 S_obtain_read_lock(PolyReader *self, const CharBuf *snapshot_filename);
-static void 
+static bool_t
 S_obtain_deletion_lock(PolyReader *self);
 static void 
 S_release_read_lock(PolyReader *self);
@@ -272,7 +271,12 @@ PolyReader_do_open(PolyReader *self, Obj *index, Snapshot *snapshot,
     PolyReader_init(self, NULL, folder, snapshot, manager, NULL);
     DECREF(folder);
 
-    if (manager) S_obtain_deletion_lock(self);
+    if (manager) {
+        if (!S_obtain_deletion_lock(self)) {
+            DECREF(self);
+            THROW(LOCKERR, "Couldn't get deletion lock");
+        }
+    }
 
     while (1) {
         CharBuf *target_snap_file;
@@ -302,7 +306,11 @@ PolyReader_do_open(PolyReader *self, Obj *index, Snapshot *snapshot,
 
         // Get a read lock on the most recent snapshot file if indicated. 
         if (manager) {
-            S_obtain_read_lock(self, target_snap_file);
+            if (!S_obtain_read_lock(self, target_snap_file)) {
+                DECREF(self);
+                THROW(LOCKERR, "Couldn't get read lock for %o",
+                      target_snap_file);
+            }
         }
 
         // Testing only. 
@@ -387,7 +395,7 @@ S_derive_folder(Obj *index)
     return folder;
 }
 
-static void
+static bool_t
 S_obtain_deletion_lock(PolyReader *self)
 {
     self->deletion_lock = IxManager_Make_Deletion_Lock(self->manager);
@@ -395,22 +403,23 @@ S_obtain_deletion_lock(PolyReader *self)
     if (!Lock_Obtain(self->deletion_lock)) {
         DECREF(self->deletion_lock);
         self->deletion_lock = NULL;
-        THROW(LOCKERR, "Couldn't get commit lock"); 
+        return false;
     }
+    return true;
 }
 
-static void
+static bool_t 
 S_obtain_read_lock(PolyReader *self, const CharBuf *snapshot_file_name)
 {
-    if (!self->manager) { return; }
     self->read_lock = IxManager_Make_Snapshot_Read_Lock(self->manager,
         snapshot_file_name);
 
     Lock_Clear_Stale(self->read_lock);
     if (!Lock_Obtain(self->read_lock)) {
         DECREF(self->read_lock);
-        THROW(LOCKERR, "Couldn't get read lock for %o", snapshot_file_name); 
+        return false;
     }
+    return true;
 }
 
 static void
@@ -469,28 +478,37 @@ PolyReader_get_seg_readers(PolyReader *self) { return self->sub_readers; }
 uint32_t
 PolyReader_sub_tick(I32Array *offsets, int32_t doc_id)
 {
-    uint32_t lo = 0;
-    uint32_t hi_tick = I32Arr_Get_Size(offsets) - 1;
-    uint32_t hi = hi_tick;
+    int32_t size = I32Arr_Get_Size(offsets);
+    if (size == 0) {
+        return 0;
+    }
     
-    while (hi >= lo) {
-        uint32_t mid = lo + ((hi - lo) / 2);
-        int32_t mid_start = I32Arr_Get(offsets, mid) + 1;
-        if (doc_id < mid_start) {
-            hi = mid - 1;
-        }
-        else if (doc_id > mid_start) {
-            lo = mid + 1;
+    int32_t lo     = -1; 
+    int32_t hi     = size;
+    while (hi - lo > 1) {
+        int32_t mid = lo + ((hi - lo) / 2); 
+        int32_t offset = I32Arr_Get(offsets, mid);
+        if (doc_id <= offset) {
+            hi = mid;
+        }   
+        else {
+            lo = mid;
+        }   
+    }
+    if (hi == size) {
+        hi--;
+    }
+
+    while (hi > 0) {
+        int32_t offset = I32Arr_Get(offsets, hi);
+        if (doc_id <= offset) {
+            hi--;
         }
         else {
-            while (   mid < hi_tick 
-                   && I32Arr_Get(offsets, mid + 1) == mid_start
-            ) {
-                mid++;
-            }
-            return mid;
+            break;
         }
     }
+
     return hi;
 }
     
